{% load compress %}
{% load static from staticfiles %}

<!DOCTYPE html>
<html>
  <head id="template-head">
    <meta http-equiv="X-UA-Compatible" content="IE=edge"/>
    <title>
      {%block title %}
        {% block pagetitle %}E-Democracia{% endblock pagetitle %} - E-Democracia
      {% endblock title %}
    </title>

    {# Favicon #}
    <link rel="apple-touch-icon" sizes="180x180" href="{% static 'img/favicon/apple-touch-icon.png' %}">
    <link rel="icon" type="image/png" href="{% static 'img/favicon/favicon-32x32.png' %}" sizes="32x32">
    <link rel="icon" type="image/png" href="{% static 'img/favicon/favicon-16x16.png' %}" sizes="16x16">
    <link rel="manifest" href="{% static 'img/favicon/manifest.json' %}">
    <link rel="mask-icon" href="{% static 'img/favicon/safari-pinned-tab.svg' %}" color="#123533">
    <link rel="shortcut icon" href="{% static 'img/favicon/favicon.ico' %}">
    <meta name="apple-mobile-web-app-title" content="e-Democracia">
    <meta name="application-name" content="e-Democracia">
    <meta name="msapplication-config" content="/static/img/favicon/browserconfig.xml">
    <meta name="theme-color" content="#123533">

    {# Styles #}
    <link rel="stylesheet" href="{% static 'fontastic-labhacker/styles.css' %}" />
    {% compress css %}
      <link rel="stylesheet" href="{% static 'scss/navigation.scss' %}" type="text/x-scss" />
      <link rel="stylesheet" href="{% static 'scss/site-wrapper.scss' %}" type="text/x-scss" />
      <link rel="stylesheet" href="{% static 'scss/wikilegis/restyle.scss' %}" type="text/x-scss" />
    {% endcompress %}
  </head>

  <body class="has-edem-nav {% if 'report' in request.path %}report{% endif %} {% if 'widget' in request.path %}widget{% endif %}">

    <nav class="navigation ">
      {% include "navigation.html" %}
    </nav>

    <div id="template-body" class="site-wrapper" style="height: 100%;">

    </div>

    <script src="https://code.jquery.com/jquery-2.2.4.min.js" integrity="sha256-BbhdlvQf/xTY9gja0Dq3HiwQF8LaCRTXxZKRutelT44=" crossorigin="anonymous"></script>
    <script type="text/javascript" src="https://npmcdn.com/headroom.js@0.9.3/dist/headroom.min.js"></script>
    <script type="text/javascript" src="{% static 'js/scripts.js' %}"></script>
  </body>
</html>
